@@ -14,7 +14,7 @@
  * (enclosed in the file GPL).
  *)
 
-(*i $Id: biboutput.ml,v 1.17 2004/10/06 06:20:00 filliatr Exp $ i*)
+(*i $Id: biboutput.ml,v 1.19 2005/12/16 08:39:35 filliatr Exp $ i*)
 
 (*s Output a BibTeX bibliography. *)
 
@@ -87,15 +87,6 @@ let print_link_field ch = function
 
 let print_command html ch keys = function 
   | Comment s -> 
-(*i
-      if html then 
-	begin
-	  Html.open_balise ch "i";
-	  output_string ch s;
-	  Html.close_balise ch "i"
-	end
-      else
-i*)
       if html then output_string ch "<pre>\n";
       output_string ch ("@COMMENT{{" ^ s ^ "}}\n");
       if html then output_string ch "</pre>\n";
